# HG changeset patch
# User Karl Heuer <kwzh@gnu.org>
# Date 799369939 0
# Node ID 748feea0a51a8b2383ccd5420f036fac42c264be
# Parent  370e1016aba28440f79e75ab6a02fe749f79d25e
(redisplay): Don't move the cursor if it's supposed to
be in the echo area.

diff -r 370e1016aba2 -r 748feea0a51a src/xdisp.c
--- a/src/xdisp.c	Mon May 01 18:26:28 1995 +0000
+++ b/src/xdisp.c	Mon May 01 23:12:19 1995 +0000
@@ -898,10 +898,12 @@
 	    }
 	  goto update;
 	}
-      /* If highlighting the region, we can't just move the cursor.  */
+      /* If highlighting the region, or if the cursor is in the echo area,
+	 then we can't just move the cursor.  */
       else if (! (!NILP (Vtransient_mark_mode)
 		  && !NILP (current_buffer->mark_active))
-	       && NILP (w->region_showing))
+	       && NILP (w->region_showing)
+	       && !cursor_in_echo_area)
 	{
 	  pos = *compute_motion (tlbufpos, 0,
 				 XINT (w->hscroll) ? 1 - XINT (w->hscroll) : 0,